unit vfonts1;

(* Visualiseur des polices de caractres
 * Copyright (C) 1998-2000 Olivier Cado
 * http://www.chez.com/ocado - ocado@chez.com
 * Version 2.0.1, February 20 2000
 *
 * Historique :
 * Version 2.0.1 : 20/02/2000 -> TRichEdit
 * Version 1.5.1 : 16/01/1999 -> TDrawGrid
 * Version 1.0.1 : 30/08/1998 -> TextOut

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 * Borland Delphi 3.0 ou suprieur est ncessaire pour compiler ce programme
 *)

interface

uses
  Windows, SysUtils, Classes, Controls, Forms, Graphics, StdCtrls, Buttons,
  ExtCtrls, ComCtrls;

type
  TForm1 = class(TForm)
    FontList: TListBox;
    EditSample: TEdit;
    ApplyButton: TButton;
    Label2: TLabel;
    EditSize: TEdit;
    Bevel1: TBevel;
    BoldButton: TSpeedButton;
    ItalicButton: TSpeedButton;
    UnderButton: TSpeedButton;
    FontNbr: TLabel;
    NameButton: TSpeedButton;
    NbrButton: TSpeedButton;
    TableButton: TBitBtn;
    RichEdit1: TRichEdit;
    PrintButton: TButton;
    CopyButton: TButton;
    HelpButton: TButton;
    BorderButton: TSpeedButton;
    WordwrapButton: TSpeedButton;
    procedure FormCreate(Sender: TObject);
    procedure ApplyButtonClick(Sender: TObject);
    procedure FontListClick(Sender: TObject);
    procedure TableButtonClick(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure PrintButtonClick(Sender: TObject);
    procedure CopyButtonClick(Sender: TObject);
    procedure BorderButtonClick(Sender: TObject);
    procedure WordwrapButtonClick(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure HelpButtonClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    ChangeText : boolean; // cf. ApplyButtonClick
  end;

  ESize = class(Exception);

var
  Form1: TForm1;

implementation

{$R *.DFM}

(********************
 * ListBoxSelectAll *
 *******************)
procedure ListBoxSelectAll(Lb : TListBox);
var
  i : integer;
begin
  with Lb do
    for i:= 0 to Items.Count-1 do Selected[i] := true; // tout slectionner
end;

(**************
 * FormCreate *
 *************)
procedure TForm1.FormCreate(Sender: TObject);
begin
  FontList.Items.Assign(Screen.Fonts);
  ApplyButtonClick(Sender);
  ListBoxSelectAll(FontList);
  Caption := Caption + ' (' + IntToStr(FontList.Items.Count) + ' polices installes)';
end;

(********************
 * ApplyButtonClick *
 *******************)
procedure TForm1.ApplyButtonClick(Sender: TObject);
var
  i : integer;
  SampleText : string;
begin
  FontNbr.Caption := '';

  with RichEdit1 do begin
    Lines.Clear;
    // Attributs communs  toutes les lignes
    with SelAttributes do begin
      if BoldButton.Down then Style := Style + [fsBold]
                         else Style := Style - [fsBold];
      if ItalicButton.Down then Style := Style + [fsItalic]
                           else Style := Style - [fsItalic];
      if UnderButton.Down then Style := Style + [fsUnderline]
                          else Style := Style - [fsUnderline];
      Size := StrToInt(EditSize.Text);
      if Size <= 0 then raise ESize.Create('Entrez une taille suprieure  zro');
      Color := clBlack;
    end;
    // Ajout de chaque ligne ({N}+{Nom}+Phrase)
    for i := 0 to FontList.Items.Count-1 do begin
      if FontList.Selected[i] then begin
        SelAttributes.Name := FontList.Items[i];
        if NbrButton.Down then SampleText := IntToStr(i+1) + ' ' else SampleText := '';
        if NameButton.Down then SampleText := SampleText + SelAttributes.Name + ' : ';
        SampleText := SampleText + EditSample.Text;
        Lines.Add( SampleText );
      end;
    end;
    // Si aucune police n'est slectionne
    if Lines.Count=0 then begin
      SelAttributes.Assign( Form1.Font );
      Lines.Add('Slectionnez des polices de caractres dans la liste de gauche, puis cliquez sur Afficher.');
    end;
  end;
end;

(*****************
 * FontListClick *
 ****************)
 procedure TForm1.FontListClick(Sender: TObject);
begin
  FontNbr.Caption := 'N'+IntToStr(FontList.ItemIndex+1);
end;

(********************
 * TableButtonClick *
 *******************)
 procedure TForm1.TableButtonClick(Sender: TObject);
begin
  if WinExec('charmap.exe',SW_SHOW) < 32 // Lance la table des caractres
  then Application.MessageBox('Impossible d''excuter le programme CHARMAP.EXE','Erreur',mb_IconStop+mb_Ok);
  ApplyButton.SetFocus;
end;

(***************
 * FormKeyDown *
 **************)
procedure TForm1.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  case Key of
   VK_F1 : HelpButtonClick(Sender);
  end;
end;

(********************
 * PrintButtonClick *
 *******************)
procedure TForm1.PrintButtonClick(Sender: TObject);
begin
  if Application.MessageBox('Souhaitez-vous vraiment imprimer, sur l''imprimante par dfaut ?',
     'Imprimer', MB_ICONQUESTION or MB_YESNO) = IDYES then
    RichEdit1.Print('Visualiseur des polices de caractres');
end;

(*******************
 * CopyButtonClick *
 ******************)
procedure TForm1.CopyButtonClick(Sender: TObject);
begin
  with RichEdit1 do begin
    SelectAll;
    CopyToClipboard;
    SelLength := 0;
  end;
end;

(*********************
 * BorderButtonClick *
 ********************)
procedure TForm1.BorderButtonClick(Sender: TObject);
begin
  with RichEdit1 do begin
    if BorderStyle=bsNone then begin
      BorderStyle := bsSingle;
      Color := clWindow;
    end else begin
      BorderStyle := bsNone;
      Color := clBtnFace;
    end;
  end;
end;

(***********************
 * WordwrapButtonClick *
 **********************)
procedure TForm1.WordwrapButtonClick(Sender: TObject);
begin
  RichEdit1.Wordwrap := not RichEdit1.Wordwrap;
end;

(**************
 * FormResize *
 *************)
procedure TForm1.FormResize(Sender: TObject);
begin
  FontList.Height := ClientHeight;
  with RichEdit1 do begin
    Height := Self.ClientHeight - Top;
    Width := Self.ClientWidth - Left;
  end;
end;

(*******************
 * HelpButtonClick *
 ******************)

procedure TForm1.HelpButtonClick(Sender: TObject);
const
  CR = #13;
  LF = #13#13;
begin
  Application.MessageBox('Visualiseur des polices de caractres 2.0.1'+CR+
     ' 1998-2000, Olivier Cado - GNU General Public License'+CR+'http://www.chez.com/ocado - ocado@chez.com'+LF+'Ce logiciel vous aide  choisir des polices de caractres '+
     'installes sur votre systme, en les comparant entre elles.'+LF+'Pour slectionner certaines polices de caractres dans la liste de gauche, '+
     'cliquez sur leur nom en maintenant ventuellement enfonce la touche Maj (groupe continu) ou la touche Ctrl '+
     '(groupe discontinu). Exemple: pour slectionner toutes les polices, cliquez sur la premire, faites ventuellement '+
     'dfiler la liste pour atteindre la dernire police, puis cliquez sur la dernire tout en appuyant sur la touche Maj. '+
     'Au dmarrage du logiciel, toutes les polices sont slectionnes.'+LF+
     'Le bouton en forme de grille sert  ouvrir la Table de Caractres qui '+
     'permet de copier des caractres spciaux dans le Presse-Papiers. Vous pouvez ensuite les coller dans le champ '+
     'de saisie de texte avec la combinaison de touches Ctrl-V ou avec un clic droit sur ce champ de texte, puis Coller.'+LF+
     'Le bouton Copier permet de copier tout vos chantillons dans le Presse-Papiers, par exemple pour voir leur apparence '+
     'dans un logiciel de traitement de textes.'+LF+
     'Vous pouvez vous dplacer dans les chantillons grce  l''ascenseur latral et au curseur. Vous pouvez mme saisir '+
     'du texte  l''intrieur de la fentre d''chantillons !',
     'A propos & Aide',mb_Ok+mb_IconInformation);
end;

(************
 * FormShow *
 ***********)
procedure TForm1.FormShow(Sender: TObject);
begin
  FormResize(Sender);
end;

end.
